@@ -51,6 +51,7 @@ if args.s:
 elif config.get('SIGNER_SOCKET_PATH'):
     socket_path = config.get('SIGNER_SOCKET_PATH')
 
+
 # connect to database
 dsn = 'postgresql://{}:{}@{}:{}/{}'.format(
         config.get('DATABASE_USER'),
@@ -60,6 +61,10 @@ dsn = 'postgresql://{}:{}@{}:{}/{}'.format(
         config.get('DATABASE_NAME'),    
     )
 
+logg.info('using dsn {}'.format(dsn))
+logg.info('using socket {}'.format(socket_path))
+
+
 class MissingSecretError(BaseException):
 
     def __init__(self, message):
