@@ -10,7 +10,7 @@ re_http = re.compile('^https?://')
 
 #def create_middleware(ipcaddr='/var/run/cic-platform/cic.ipc'):
 def create_middleware(ipcpath):
-    PlatformMiddleware.ipcaddr = ipcpath
+    #PlatformMiddleware.ipcaddr = ipcpath
     return PlatformMiddleware
 
 
