@@ -23,12 +23,15 @@ class PlatformMiddleware:
     # hack workaround
     id_seq = -1
     re_personal = re.compile('^personal_.*')
-    ipcaddr = '/tmp/foo.ipc'
+    ipcaddr = '/run/crypto-dev-signer/jsonrpc.ipc'
 
 
-    def __init__(self, make_request, w3):
+    def __init__(self, make_request, w3, ipcaddr=None):
         self.w3 = w3 
         self.make_request = make_request
+        if ipcaddr != None:
+            PlatformMiddleware.ipcaddr = ipcaddr
+
 
     
     # TODO: understand what format input params come in
@@ -51,13 +54,13 @@ class PlatformMiddleware:
     def __call__(self, method, suspect_params):
 
         self.id_seq += 1
-        logg.debug('in middleware method {} params {}'.format(method, suspect_params))
+        logg.debug('in middleware method {} params {} ipcpath {}'.format(method, suspect_params, self.ipcaddr))
 
         if self.re_personal.match(method) != None:
             params = PlatformMiddleware._translate_params(suspect_params)
-            # multiple providers is broken in web3.py 5.12.0
+            # multiple providers is removed in web3.py 5.12.0
             # https://github.com/ethereum/web3.py/issues/1701
-            # hack workaround
+            # thus we need a workaround to use the same web3 instance
             s = socket.socket(family=socket.AF_UNIX, type=socket.SOCK_STREAM, proto=0)
             ipc_provider_workaround = s.connect(self.ipcaddr)
 
@@ -74,6 +77,7 @@ class PlatformMiddleware:
             #return str(json.dumps(jr))
             return jr
 
+        # TODO: DRY
         elif method == 'eth_signTransaction':
             params = PlatformMiddleware._translate_params(suspect_params)
             s = socket.socket(family=socket.AF_UNIX, type=socket.SOCK_STREAM, proto=0)
